| is_idn | R Documentation |
Determines whether a domain name contains Unicode characters that would require punycode encoding for ASCII compatibility.
is_idn(x)
x |
Character vector of domain names to test |
A logical vector the same length as x, where TRUE
indicates the element contains non-ASCII Unicode characters.
is_punycode for detecting punycode domains,
puny_encode for encoding Unicode domains.
is_idn("caf\u00E9.com") # TRUE
is_idn("example.com") # FALSE
is_idn(c(
"caf\u00E9.com",
"\u043C\u043E\u0441\u043A\u0432\u0430.\u0440\u0444",
"test.com"
)) # c(TRUE, TRUE, FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.