| is_punycode | R Documentation |
Determines whether a given string or domain name is already encoded in punycode format (starts with xn– prefix).
is_punycode(x)
x |
Character vector to test |
A logical vector the same length as x, where TRUE
indicates the element contains a punycode-encoded label (xn– prefix).
is_idn for detecting Unicode domains,
puny_decode for decoding punycode domains.
is_punycode("xn--example") # TRUE
is_punycode("example.com") # FALSE
is_punycode(c("xn--caf-dma.com", "regular.com")) # c(TRUE, FALSE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.