Learn R Programming

punycoder (version 1.1.0)

is_punycode: Test if string is punycode encoded

Description

Determines whether a given string or domain name is already encoded in punycode format (starts with xn-- prefix).

Usage

is_punycode(x)

Value

A logical vector the same length as x, where TRUE

indicates the element contains a punycode-encoded label (xn-- prefix).

Arguments

x

Character vector to test

See Also

is_idn for detecting Unicode domains, puny_decode for decoding punycode domains.

Examples

Run this code
# \donttest{
is_punycode("xn--example") # TRUE
is_punycode("example.com") # FALSE
is_punycode(c("xn--caf-dma.com", "regular.com"))  # c(TRUE, FALSE)
# }

Run the code above in your browser using DataLab