powered by
Determines whether a given string or domain name is already encoded in punycode format (starts with xn-- prefix).
is_punycode(x)
A logical vector the same length as x, where TRUE
x
TRUE
indicates the element contains a punycode-encoded label (xn-- prefix).
Character vector to test
is_idn for detecting Unicode domains, puny_decode for decoding punycode domains.
is_idn
puny_decode
# \donttest{ is_punycode("xn--example") # TRUE is_punycode("example.com") # FALSE is_punycode(c("xn--caf-dma.com", "regular.com")) # c(TRUE, FALSE) # }
Run the code above in your browser using DataLab